@@ -91,7 +91,7 @@ gpm_brightness_xrandr_output_get_internal (GpmBrightnessXRandR *brightness, RROu
 {
 	unsigned long nitems;
 	unsigned long bytes_after;
-	unsigned char *prop;
+	guint *prop;
 	Atom actual_type;
 	int actual_format;
 	gboolean ret = FALSE;
@@ -101,7 +101,7 @@ gpm_brightness_xrandr_output_get_internal (GpmBrightnessXRandR *brightness, RROu
 	if (XRRGetOutputProperty (brightness->priv->dpy, output, brightness->priv->backlight,
 				  0, 4, False, False, None,
 				  &actual_type, &actual_format,
-				  &nitems, &bytes_after, &prop) != Success) {
+				  &nitems, &bytes_after, ((unsigned char **)&prop)) != Success) {
 		egg_debug ("failed to get property");
 		return FALSE;
 	}
@@ -584,9 +584,7 @@ gpm_brightness_xrandr_filter_xevents (GdkXEvent *xevent, GdkEvent *event, gpoint
 	GpmBrightnessXRandR *brightness = GPM_BRIGHTNESS_XRANDR (data);
 	if (event->type == GDK_NOTHING)
 		return GDK_FILTER_CONTINUE;
-	egg_warning ("Type %i", event->type);
-	if (FALSE)
-		gpm_brightness_xrandr_may_have_changed (brightness);
+	gpm_brightness_xrandr_may_have_changed (brightness);
 	return GDK_FILTER_CONTINUE;
 }
 
@@ -609,7 +607,6 @@ gpm_brightness_monitors_changed (GdkScreen *screen, GpmBrightnessXRandR *brightn
 static void
 gpm_brightness_xrandr_update_cache (GpmBrightnessXRandR *brightness)
 {
-	guint i;
 	guint length;
 	gint screen;
 	Window root;
@@ -621,13 +618,8 @@ gpm_brightness_xrandr_update_cache (GpmBrightnessXRandR *brightness)
 
 	/* invalidate and remove all the previous entries */
 	length = brightness->priv->resources->len;
-	for (i=0; i<length; i++) {
-		resource = (XRRScreenResources *) g_ptr_array_index (brightness->priv->resources, i);
-		egg_debug ("freeing resource %p", resource);
-		XRRFreeScreenResources (resource);
-	}
 	if (length > 0)
-		g_ptr_array_remove_range (brightness->priv->resources, 0, length);
+		g_ptr_array_set_size (brightness->priv->resources, 0);
 
 	/* do for each screen */
 	display = gdk_display_get_default ();
@@ -676,8 +668,7 @@ gpm_brightness_xrandr_finalize (GObject *object)
 	g_return_if_fail (GPM_IS_BRIGHTNESS_XRANDR (object));
 	brightness = GPM_BRIGHTNESS_XRANDR (object);
 
-	g_ptr_array_foreach (brightness->priv->resources, (GFunc) XRRFreeScreenResources, NULL);
-	g_ptr_array_free (brightness->priv->resources, FALSE);
+	g_ptr_array_unref (brightness->priv->resources);
 
 	G_OBJECT_CLASS (gpm_brightness_xrandr_parent_class)->finalize (object);
 }
@@ -716,7 +707,7 @@ gpm_brightness_xrandr_init (GpmBrightnessXRandR *brightness)
 
 	brightness->priv = GPM_BRIGHTNESS_XRANDR_GET_PRIVATE (brightness);
 	brightness->priv->hw_changed = FALSE;
-	brightness->priv->resources = g_ptr_array_new ();
+	brightness->priv->resources = g_ptr_array_new_with_free_func ((GDestroyNotify) XRRFreeScreenResources);
 
 	/* can we do this */
 	brightness->priv->has_extension = gpm_brightness_xrandr_setup_display (brightness);
