@@ -50,9 +50,9 @@ gpm_disks_unregister (GpmDisks *disks)
 	gboolean ret = FALSE;
 	GError *error = NULL;
 
-	/* no DeviceKit-power */
+	/* no DeviceKit-disks */
 	if (disks->priv->proxy == NULL) {
-		egg_warning ("no DeviceKit-power");
+		egg_warning ("no DeviceKit-disks");
 		goto out;
 	}
 
@@ -78,15 +78,15 @@ out:
  * gpm_disks_register:
  **/
 static gboolean
-gpm_disks_register (GpmDisks *disks, guint timeout)
+gpm_disks_register (GpmDisks *disks, gint timeout)
 {
 	gboolean ret = FALSE;
 	GError *error = NULL;
 	const gchar **options = {NULL};
 
-	/* no DeviceKit-power */
+	/* no DeviceKit-disks */
 	if (disks->priv->proxy == NULL) {
-		egg_warning ("no DeviceKit-power");
+		egg_warning ("no DeviceKit-disks");
 		goto out;
 	}
 
@@ -95,7 +95,7 @@ gpm_disks_register (GpmDisks *disks, guint timeout)
 				 G_TYPE_INT, timeout,
 				 G_TYPE_STRV, options,
 				 G_TYPE_INVALID,
-				 G_TYPE_STRING, disks->priv->cookie,
+				 G_TYPE_STRING, &disks->priv->cookie,
 				 G_TYPE_INVALID);
 	if (!ret) {
 		egg_warning ("failed to set spindown timeout: %s", error->message);
@@ -110,7 +110,7 @@ out:
  * gpm_disks_set_spindown_timeout:
  **/
 gboolean
-gpm_disks_set_spindown_timeout (GpmDisks *disks, guint timeout)
+gpm_disks_set_spindown_timeout (GpmDisks *disks, gint timeout)
 {
 	gboolean ret = TRUE;
 
