@@ -35,6 +35,7 @@
 #endif /* HAVE_UNISTD_H */
 
 #include <glib.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
 #include "egg-debug.h"
@@ -49,7 +50,6 @@
 /* Sets the idle percent limit, i.e. how hard the computer can work
    while considered "at idle" */
 #define GPM_IDLE_CPU_LIMIT			5
-#define GPM_IDLE_TIMEOUT_IGNORE_DPMS_CHANGE	1.0f /* seconds */
 #define	GPM_IDLE_IDLETIME_ID			1
 
 struct GpmIdlePrivate
@@ -66,7 +66,6 @@ struct GpmIdlePrivate
 	guint		 timeout_sleep_id;
 	gboolean	 x_idle;
 	gboolean	 check_type_cpu;
-	GTimer		*timer;
 };
 
 enum {
@@ -102,15 +101,11 @@ gpm_idle_mode_to_text (GpmIdleMode mode)
 static const gchar *
 gpm_idle_mode_to_icon_name (GpmIdleMode mode)
 {
-	if (mode == GPM_IDLE_MODE_NORMAL)
-		return "computer";
-	if (mode == GPM_IDLE_MODE_DIM)
-		return "video-display";
 	if (mode == GPM_IDLE_MODE_BLANK)
 		return "view-fullscreen";
 	if (mode == GPM_IDLE_MODE_SLEEP)
 		return "system-log-out";
-	return "unknown";
+	return NULL;
 }
 
 /**
@@ -125,18 +120,16 @@ gpm_idle_set_mode (GpmIdle *idle, GpmIdleMode mode)
 	g_return_if_fail (GPM_IS_IDLE (idle));
 
 	/* debug */
-	if (idle->priv->status_icon != NULL) {
-		icon_name = gpm_idle_mode_to_icon_name (mode);
+	icon_name = gpm_idle_mode_to_icon_name (mode);
+	if (icon_name != NULL) {
 		gtk_status_icon_set_from_icon_name (idle->priv->status_icon, icon_name);
+		gtk_status_icon_set_visible (idle->priv->status_icon, TRUE);
+	} else {
+		gtk_status_icon_set_visible (idle->priv->status_icon, FALSE);
 	}
 
 	if (mode != idle->priv->mode) {
 		idle->priv->mode = mode;
-
-		/* we save the time of the last state, so we can ignore the X11
-		 * timer reset when we change brightness or do DPMS actions */
-		g_timer_reset (idle->priv->timer);
-
 		egg_debug ("Doing a state transition: %s", gpm_idle_mode_to_text (mode));
 		g_signal_emit (idle, signals [IDLE_CHANGED], 0, mode);
 	}
@@ -212,17 +205,32 @@ gpm_idle_evaluate (GpmIdle *idle)
 	gboolean is_idle;
 	gboolean is_inhibited;
 	gchar *tooltip;
+	gchar *what_to_do;
+	gchar *nag_message;
 
 	is_idle = gpm_session_get_idle (idle->priv->session);
 	is_inhibited = gpm_session_get_inhibited (idle->priv->session);
 	egg_debug ("session_idle=%i, session_inhibited=%i, x_idle=%i", is_idle, is_inhibited, idle->priv->x_idle);
 
+	/* TRANSLATORS: this is what the user should read for more information about the blanking problem (%s is a URL) */
+	what_to_do = g_strdup_printf (_("Please see %s for more information."),
+				      "http://blogs.gnome.org/hughsie/2009/08/17/gnome-power-manager-and-blanking-removal-of-bodges/");
+
+	/* TRANSLATORS: this is telling the user that thier X server is broken, and needs to be fixed */
+	nag_message = g_strdup_printf ("%s\n%s", _("If you can see this text, your display server is broken and you should notify your distributor."),
+				       what_to_do);
+
 	/* debug */
-	if (idle->priv->status_icon != NULL) {
-		tooltip = g_strdup_printf ("session_idle=%i, session_inhibited=%i, x_idle=%i", is_idle, is_inhibited, idle->priv->x_idle);
-		gtk_status_icon_set_tooltip_text (idle->priv->status_icon, tooltip);
-		g_free (tooltip);
-	}
+	tooltip = g_strdup_printf ("%s, %s, %s.\n%s",
+				   /* TRANSLATORS: this is for debugging, if the session is idle */
+				   is_idle ? _("Session idle") : _("Session active"),
+				   /* TRANSLATORS: has something inhibited the session */
+				   is_inhibited ? _("inhibited") : _("not inhibited"),
+				   /* TRANSLATORS: is the screen idle or awake */
+				   idle->priv->x_idle ? _("screen idle") : _("screen awake"),
+				   nag_message);
+	gtk_status_icon_set_tooltip_text (idle->priv->status_icon, tooltip);
+	g_free (tooltip);
 
 	/* check we are really idle */
 	if (!idle->priv->x_idle) {
@@ -277,6 +285,8 @@ gpm_idle_evaluate (GpmIdle *idle)
 		}
 	}
 out:
+	g_free (nag_message);
+	g_free (what_to_do);
 	return;
 }
 
@@ -355,14 +365,6 @@ static void
 gpm_idle_session_inhibited_changed_cb (GpmSession *session, gboolean is_inhibited, GpmIdle *idle)
 {
 	egg_debug ("Received gnome session inhibited changed: %i", is_inhibited);
-
-	/* gnome-session IDLETIME bug -- For more details see:
-	 * http://blogs.gnome.org/hughsie/2009/07/30/accidental-blanking-and-gnome-power-manager/ */
-	if (!is_inhibited) {
-		egg_warning ("performing gnome-session IDLETIME bodge");
-		egg_idletime_alarm_reset_all (idle->priv->idletime);
-	}
-
 	gpm_idle_evaluate (idle);
 }
 
@@ -374,10 +376,7 @@ gpm_idle_session_inhibited_changed_cb (GpmSession *session, gboolean is_inhibite
 static void
 gpm_idle_idletime_alarm_expired_cb (EggIdletime *idletime, guint alarm_id, GpmIdle *idle)
 {
-	egg_warning ("idletime alarm: %i", alarm_id);
-
-	/* reset time to dim default (could be 1ms) */
-	egg_idletime_alarm_set (idle->priv->idletime, GPM_IDLE_IDLETIME_ID, idle->priv->timeout_dim * 1000);
+	egg_debug ("idletime alarm: %i", alarm_id);
 
 	/* set again */
 	idle->priv->x_idle = TRUE;
@@ -392,19 +391,7 @@ gpm_idle_idletime_alarm_expired_cb (EggIdletime *idletime, guint alarm_id, GpmId
 static void
 gpm_idle_idletime_reset_cb (EggIdletime *idletime, GpmIdle *idle)
 {
-	gdouble elapsed;
-	elapsed = g_timer_elapsed (idle->priv->timer, NULL);
-
-	egg_warning ("idletime reset");
-
-	/* have we just chaged state? */
-	if (idle->priv->mode == GPM_IDLE_MODE_BLANK &&
-	    elapsed < GPM_IDLE_TIMEOUT_IGNORE_DPMS_CHANGE) {
-		egg_debug ("ignoring reset, as we've just done a state change");
-		/* make sure we trigger a short 1ms timeout so we can get the expired signal */
-		egg_idletime_alarm_set (idle->priv->idletime, GPM_IDLE_IDLETIME_ID, 1);
-		return;
-	}
+	egg_debug ("idletime reset");
 
 	idle->priv->x_idle = FALSE;
 	gpm_idle_evaluate (idle);
@@ -432,10 +419,8 @@ gpm_idle_finalize (GObject *object)
 		g_source_remove (idle->priv->timeout_sleep_id);
 
 	/* for debugging */
-	if (idle->priv->status_icon != NULL)
-		g_object_unref (idle->priv->status_icon);
+	g_object_unref (idle->priv->status_icon);
 
-	g_timer_destroy (idle->priv->timer);
 	g_object_unref (idle->priv->load);
 	g_object_unref (idle->priv->session);
 
@@ -479,14 +464,12 @@ gpm_idle_init (GpmIdle *idle)
 {
 	idle->priv = GPM_IDLE_GET_PRIVATE (idle);
 
-	idle->priv->status_icon = NULL;
 	idle->priv->timeout_dim = G_MAXUINT;
 	idle->priv->timeout_blank = G_MAXUINT;
 	idle->priv->timeout_sleep = G_MAXUINT;
 	idle->priv->timeout_blank_id = 0;
 	idle->priv->timeout_sleep_id = 0;
 	idle->priv->x_idle = FALSE;
-	idle->priv->timer = g_timer_new ();
 	idle->priv->load = gpm_load_new ();
 	idle->priv->session = gpm_session_new ();
 	g_signal_connect (idle->priv->session, "idle-changed", G_CALLBACK (gpm_idle_session_idle_changed_cb), idle);
@@ -497,11 +480,7 @@ gpm_idle_init (GpmIdle *idle)
 	g_signal_connect (idle->priv->idletime, "alarm-expired", G_CALLBACK (gpm_idle_idletime_alarm_expired_cb), idle);
 
 	/* only used for debugging */
-	if (g_getenv ("GPMIDLEDEBUG") != NULL) {
-		idle->priv->status_icon = gtk_status_icon_new ();
-		gtk_status_icon_set_from_icon_name (idle->priv->status_icon, "edit-find");
-		gtk_status_icon_set_visible (idle->priv->status_icon, TRUE);
-	}
+	idle->priv->status_icon = gtk_status_icon_new ();
 
 	gpm_idle_evaluate (idle);
 }
