@@ -35,14 +35,13 @@
 #include <gtk/gtk.h>
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
-#include <glade/glade.h>
 
 #include "gpm-stock-icons.h"
 #include "gpm-common.h"
 #include "gpm-manager.h"
 #include "gpm-session.h"
 
-#include "org.freedesktop.PowerManagement.h"
+#include "org.gnome.PowerManager.h"
 
 #include "egg-debug.h"
 
@@ -51,7 +50,7 @@
  * @connection: What we want to register to
  * @object: The GObject we want to register
  *
- * Register org.freedesktop.PowerManagement on the session bus.
+ * Register org.gnome.PowerManager on the session bus.
  * This function MUST be called before DBUS service will work.
  *
  * Return value: success
@@ -165,6 +164,7 @@ main (int argc, char *argv[])
 	GpmManager *manager = NULL;
 	GError *error = NULL;
 	GOptionContext *context;
+	gint ret;
 
 	const GOptionEntry options[] = {
 		{ "verbose", '\0', 0, G_OPTION_ARG_NONE, &verbose,
@@ -251,6 +251,21 @@ main (int argc, char *argv[])
 		return 0;
 	}
 
+	/* register to be a policy agent, just like kpackagekit does */
+	ret = dbus_bus_request_name(dbus_g_connection_get_connection(system_connection),
+				    "org.freedesktop.Policy.Power",
+				    DBUS_NAME_FLAG_REPLACE_EXISTING, NULL);
+	switch (ret) {
+	case DBUS_REQUEST_NAME_REPLY_PRIMARY_OWNER:
+		egg_debug ("Successfully acquired interface org.freedesktop.Policy.Power.");
+		break;
+	case DBUS_REQUEST_NAME_REPLY_IN_QUEUE:
+		egg_debug ("Queued for interface org.freedesktop.Policy.Power.");
+		break;
+	default:
+		break;
+	};
+
 	/* Only timeout and close the mainloop if we have specified it
 	 * on the command line */
 	if (timed_exit) {
