@@ -26,19 +26,16 @@
 
 G_BEGIN_DECLS
 
-#define GPM_STOCK_APP_ICON			"gpm-primary-charged"
+#define GPM_STOCK_APP_ICON			"gnome-power-manager"
 #define GPM_STOCK_AC_ADAPTER			"gpm-ac-adapter"
 #define GPM_STOCK_BATTERY_CHARGED		"gpm-primary-charged"
 #define GPM_STOCK_HIBERNATE			"gpm-hibernate"
 #define GPM_STOCK_SUSPEND			"gpm-suspend"
-#define GPM_STOCK_STATISTICS			"gpm-statistics"
+#define GPM_STOCK_STATISTICS			"gnome-power-statistics"
 #define GPM_STOCK_BRIGHTNESS_LCD		"gpm-brightness-lcd"
 #define GPM_STOCK_BRIGHTNESS_KBD		"gpm-brightness-kbd"
 #define GPM_STOCK_INHIBIT			"gpm-inhibit"
 
-gboolean	gpm_stock_icons_init			(void);
-void		gpm_stock_icons_shutdown		(void);
-
 G_END_DECLS
 
 #endif /* __GPM_STOCK_ICONS_H */
